"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isBrowser = exports.isBetweenDates = exports.isFile = exports.groupArticlesByDate = exports.getApiResourceKey = exports.formatDate = exports.getResourceUrl = exports.getFieldValueByFieldLabel = exports.getDisplayDate = exports.getFullSlug = void 0;
const enums_1 = require("./enums");
const getFullSlug = (article) => {
    const lastSlashPos = article.url.lastIndexOf('/');
    const secondLastSlashPos = article.url
        .substring(0, lastSlashPos - 1)
        .lastIndexOf('/');
    return article.url.substring(secondLastSlashPos);
};
exports.getFullSlug = getFullSlug;
function getDisplayDate(date, withTime = false, showDayName = false, showTimeOnly = false) {
    const localeMap = {
        en: 'en-US',
        es: 'es-ES',
        nl: 'nl-NL',
        de: 'de-DE',
    };
    let language = 'en';
    if (typeof window !== 'undefined') {
        language = window.localStorage.getItem('language') || 'en';
    }
    const locale = localeMap[language];
    const myDate = Date.parse(date);
    const d1 = new Date(myDate);
    const month = d1.toLocaleString(locale, { month: 'long' });
    const day = d1.toLocaleString(locale, { day: '2-digit' });
    const weekDay = d1.toLocaleString(locale, { weekday: 'long' });
    const year = d1.toLocaleString(locale, { year: 'numeric' });
    const timeFormatted = d1.toLocaleString(locale, {
        timeStyle: 'short',
        hourCycle: 'h24',
    });
    if (!showTimeOnly) {
        return `${showDayName ? weekDay + ', ' : ''} ${day} ${month} ${year} ${withTime ? ` at ${timeFormatted}` : ''}`;
    }
    else {
        return ` ${timeFormatted}`;
    }
}
exports.getDisplayDate = getDisplayDate;
/**
 * This function is used to return the value of IFieldBlock "lib/models/IFieldBlock" which has
 * label equal to @param label
 *
 * @returns Object
 */
const getFieldValueByFieldLabel = (label, fields) => {
    let filterFn;
    if (fields?.length) {
        if (fields[0].label)
            filterFn = (item) => item?.label === label;
        else
            filterFn = (item) => item.field?.label === label;
    }
    else {
        return false;
    }
    const result = fields.filter(filterFn);
    return result ? result[0]?.value : false;
};
exports.getFieldValueByFieldLabel = getFieldValueByFieldLabel;
/**
 * this function will @returns string
 * the return value is arilative URL for any resourse[artical,tag,collection-item,...]
 */
const getResourceUrl = (resource, resourceType) => {
    let resourceUrl = '';
    if (resourceType === enums_1.RESOURCE.Article) {
        const article = resource;
        resourceUrl = `/${article.primary_tag.slug}/${article.slug}`;
    }
    if (resourceType === enums_1.RESOURCE.Collection) {
        resourceUrl = `/${resource.slug}`;
    }
    if (resourceType === enums_1.RESOURCE.CollectionItem) {
        const collectionItem = resource;
        resourceUrl = `/${collectionItem.collection.slug}/${collectionItem.slug}`;
    }
    if (resourceType === enums_1.RESOURCE.Tag) {
        resourceUrl = `/${resource.slug}`;
    }
    if (resourceType === enums_1.RESOURCE.Forum) {
        resourceUrl = `/forum/${resource.slug}`;
    }
    return resourceUrl;
};
exports.getResourceUrl = getResourceUrl;
const formatDate = (dateStr) => {
    const date = new Date(dateStr);
    return `${date.getDate().toString().padStart(2, '0')}-${(date.getMonth() + 1)
        .toString()
        .padStart(2, '0')}-${date.getFullYear().toString().padStart(2, '0')}`;
};
exports.formatDate = formatDate;
/**
 * ex:collection-item is tag actually
 * @param resource
 * @returns article ,tag, collection, page
 */
const getApiResourceKey = (resource) => {
    return resource === enums_1.RESOURCE.CollectionItem ? enums_1.RESOURCE.Tag : resource;
};
exports.getApiResourceKey = getApiResourceKey;
const groupArticlesByDate = (articles) => {
    const groupedArticlesObj = {};
    articles.reduce((prev, currArticle) => {
        const dateStr = (0, exports.formatDate)(currArticle.published_at);
        if (!groupedArticlesObj[dateStr])
            groupedArticlesObj[dateStr] = [];
        groupedArticlesObj[dateStr].push(currArticle);
        return prev;
    }, groupedArticlesObj);
    const sortedArticlesArr = Object.keys(groupedArticlesObj).map((dateStr) => {
        return groupedArticlesObj[dateStr];
    });
    return sortedArticlesArr;
};
exports.groupArticlesByDate = groupArticlesByDate;
const isFile = (slug) => {
    const regex = /[^\\]*\.(\w+)$/;
    return slug.match(regex) !== null;
};
exports.isFile = isFile;
const isBetweenDates = (startDate, endDate) => {
    const d1 = new Date(startDate);
    const d2 = new Date(endDate);
    const d3 = new Date();
    return d3 > d1 && d3 < d2;
};
exports.isBetweenDates = isBetweenDates;
const isBrowser = () => typeof window !== 'undefined';
exports.isBrowser = isBrowser;
