import * as React from 'react';
import { FieldErrors, FieldValues, UseFormGetValues, UseFormRegister, UseFormReset, UseFormSetError, UseFormWatch } from 'react-hook-form';
import { ARTICLESLIST_LAYOUT_TYPE, ARTICLES_SCOPE, ARTICLE_HEADER_TITLE_ALIGNMENT, ARTICLE_HEADER_TITLE_LOCATION, ARTICLE_HEADLINE, ARTICLE_TYPE, ARTICLE_VIEW_TYPES, BLOCK, DEVIDER_BREADCRUMB, FEATURED_MOBILE, GRID_DIMENSIONS, HOMEICON_BREADCRUMB, HOMETYPE_BREADCRUMB, LAYOUT_TYPE, RESOURCE, SIZE, SIZES_OPTIONS, SMALL_FEATURED_NUM, TAB_STYLES, VISIBILITY } from './enums';
export interface IHeaderProps {
    logoUrl?: string;
    brand?: string;
    hasSocialIcons?: boolean;
    routesList: Array<Route>;
    user?: IUser | undefined;
    socialLinks?: {
        [key: string]: string;
    };
    mobileRoutesList?: Array<Route>;
    isAuthenticated?: boolean;
    onAuthClick?: () => void;
    notifications: {
        notifications: INotification[];
        settingsRoute: string;
        reloadNotifications: any;
        handleReadAllNotifications: () => void;
        handleReadNotificationById?: (id: any) => void;
        paginate: () => void;
        newNotificationsCount: number;
        clearNewNotifications: () => void;
        labels: {
            title: string;
            readAll: string;
            readMore: string;
            settings: string;
        };
    };
    search: {
        submit: any;
        register: any;
        placeholder?: string;
    };
    darkMode?: {
        isDarkMode: boolean;
        toggleDarkMode: () => void;
    };
}
export declare type TEmbedContentProps = {
    service: string;
    source: string;
    embed: string;
    width: number;
    height: number;
    caption: string;
};
export interface IUser {
    id: number;
    name: string;
    username: string;
    email: string;
    provider: string | null;
    provider_id: string | null;
    fb_user_access_token?: null;
    image: string;
    status: string;
    custom_data: {
        test: string;
        android_telefoon: string;
    };
    date_of_birth: string;
    settings: {
        night_mode: boolean;
        notifications?: boolean;
        notify_by_likes: boolean;
        notify_by_replies: boolean;
        notify_by_likes_on_email?: boolean;
        notify_by_replies_on_email?: boolean;
    };
    last_login: string;
    created_at?: string;
    updated_at?: string;
    is_public: boolean;
    enable_notifications_popup: boolean;
    claps_count: number;
    profile_image: string;
    origin_profile_image: string;
}
export declare type Route = {
    id: number;
    name: string;
    resource_type?: string;
    resource_id?: number | null;
    order?: number;
    destination?: string;
    url: string;
    children?: Array<Route> | [];
};
export declare type THomePageContext = {
    data: {
        bigArticles?: TArticle[] | [];
        smallArticles?: TArticle[] | [];
        hideSmallArticlesOnMobile?: boolean;
    };
};
export declare type TArticleDetailsPageContext = {
    article: IArticle | undefined;
};
export interface TFeaturedArticlesListProps {
    data: {
        bigArticles?: TArticle[];
        smallArticles?: TArticle[];
        hideSmallArticlesOnMobile?: boolean;
    };
    showCounts: boolean;
    showDate: boolean;
    showTag: boolean;
}
export declare type TFeaturedArticlesListContaier = {
    Component: React.FC<TFeaturedArticlesListProps>;
    options: {
        showCounts: boolean;
        showDate: boolean;
        showTag: boolean;
    };
};
export declare type TArticleDetailsContainer = {
    Component: React.FC<TArticleDetailsProps>;
};
export declare type TArticleDetailsProps = {
    article: IArticle;
};
export declare type TSummeryArticlesListProps = {
    options: any;
    data: UseArticlesListData;
};
export declare type TSummeryArticlesListContainer = {
    Component: React.FC<TSummeryArticlesListProps>;
    options: any;
    hookConfig: any;
    data: UseArticlesListData;
};
export declare type UseArticlesListData = {
    title: string;
    articles: IArticle[];
    groupedArticles?: {
        [key: string]: IArticle[];
    };
    group: string;
    loading: boolean;
    hasPagination?: boolean;
    paginationLabel?: string;
    paginate?: (e?: any) => void;
    handleEmitAbTestResult?: (e?: any) => void;
};
export declare type TBreadCrumbProps = {
    basePath?: string;
    pathes: Array<Route>;
};
export declare type TBreadCrumbContainer = {
    Component: React.FC<TBreadCrumbProps>;
};
export declare type TArticlesListProps = {
    data: UseArticlesListData;
};
export declare type TArticlesListContaier = {
    hookConfig: any;
    Component: React.FC<TArticlesListProps & TArticleListOptions & {
        loader: any;
    }>;
    options: TArticleListOptions;
};
export declare type TArticle = {
    id: number;
    slug: string;
    title: string;
    a_title: string;
    b_title: string;
    abtesting: boolean;
    excerpt: string;
    author: IAuthor;
    published_at: string;
    updated_at: string;
    disable_ads: boolean;
    image: string;
    primary_tag: ITag;
    tags: ITag[];
    comments_count: number;
    claps_count: number;
    claps_users_count: number;
    views: number;
    content: {
        time: number;
        blocks: TBlock[];
        version: string;
    };
    related_articles: IRelatedArticle[];
    related_polls: IArticlePoll[];
    related_items: number[];
    content_images: IContentImage[];
    url: string;
    meta_title: string;
    meta_description: string;
    thumbnails: IThumbnails;
    thumbnails_without_watermark: IThumbnails;
    rrsLink?: string;
    type: ARTICLE_TYPE;
    in_headline: ARTICLE_HEADLINE;
    enable_comments: boolean;
    is_bold: boolean;
    source: string;
    source_url: string;
};
export declare type TClapsButtonProps = {
    usersCount: number;
    clapsCount: number;
    clapResource: () => void;
};
export interface ICommentFormData {
    content: string;
}
export interface IUseCommentFormHookData extends IFormControllerProps<ICommentFormData> {
    isReply?: boolean;
    isUpdate?: boolean;
    labels: {
        label: string;
        placeholder: string;
        cancle: string;
        submit: {
            update: string;
            reply: string;
            comment: string;
        };
    };
}
export interface IUseCommentListenerHookProps {
    resourceId: number;
    resourceType: RESOURCE;
    setCommentsCount: React.Dispatch<React.SetStateAction<number>>;
    handleLoadComments: (offest?: number) => void;
}
export interface IUseCommentFormHookProps {
    isReply?: boolean;
    isUpdate?: boolean;
    defaultComment?: string;
    hideCommentBox?: (e?: any) => void;
    handleCommentAction: (comment: string) => void;
}
export declare type NewCommentNotification = {
    resource_id: number;
    resource_type: RESOURCE;
    user_id: number;
};
export interface IUseCommentHookProps {
    level?: number;
    parentId?: number;
    comment: Comment;
    setCommentsCount: React.Dispatch<React.SetStateAction<number>>;
    comments: Comment[];
    setComments: React.Dispatch<React.SetStateAction<Comment[]>>;
    resourceType: RESOURCE;
    resourceId: number;
}
export interface IUseCommentListenerHookData {
    newCommentsCount: number;
    handReleLoadComments: (e: React.MouseEvent<HTMLButtonElement>) => void;
}
export declare type TInteractiveCommentsContainer = {
    Component: React.FC<IUseCommentsHookData & {
        t?: any;
    }>;
    options: {
        resourceType?: RESOURCE;
    };
};
export interface ITag {
    id: number;
    comments_count?: number;
    enable_comments?: boolean;
    title: string;
    meta_title: string;
    url: string;
    slug: string;
    claps_users_count: number;
    claps_count: number;
    content?: {
        time: number;
        blocks: BlockType[];
        version: string;
    };
    collection_id?: number;
}
export declare type TBlock = ParagraphType | HeadingType | TableType | ListType | EmbedType | CollectionItemType | RelatedArticlesType | EditorLiveBlogType | EditorImageType;
export interface IRelatedArticle {
    id: number;
    title: string;
    slug: string;
    url: string;
    image: string;
    image_origin_url: string;
}
export interface IContentImage {
    id: number;
    url: string;
    numeration?: string;
    caption?: string;
    origin_url: string;
    watermark?: string;
}
export interface IArticlePoll {
    id: number;
    question: string;
    status: string;
    answers: {
        id: number;
        answer: string;
    }[];
}
export interface IRelatedArticle {
    id: number;
    title: string;
    slug: string;
    url: string;
    image: string;
    image_origin_url: string;
}
export interface ISmartbar {
    text: string;
    button_text: string;
    link: string;
    visibility: VISIBILITY;
    links: string[];
    start_at: string;
    date: string;
    end_at: string;
}
export declare type ParamsType = {
    [slug: string]: any;
};
export declare type ParagraphType = {
    data: {
        map?: {
            [key: string]: string;
        };
        text: string;
    };
    type: BLOCK.Paragraph;
};
export declare type HeadingType = {
    data: {
        text: string;
        level: number;
    };
    type: BLOCK.Heading;
};
export declare type TableType = {
    data: {
        content: string[][];
    };
    type: BLOCK.Table;
};
export declare type ListType = {
    data: {
        items: string[];
        style: 'ordered' | 'unordered';
    };
    type: BLOCK.List;
};
export declare type EmbedType = {
    data: {
        embed: string;
        width: number;
        height: number;
        source: string;
        caption: string;
        service: 'youtube' | 'twitter' | 'instagram';
    };
    type: BLOCK.Embed;
};
export declare type PollType = {
    data: {
        poll_id: number;
    };
    type: BLOCK.Poll;
};
export declare type EditorLiveBlogType = {
    data: {
        text: string;
    };
    type: BLOCK.EditorLiveBlog;
};
export declare type EditorImageType = {
    data: {
        id: string;
        url: string;
        link: string;
        width: string;
        height: string;
        caption: string;
        numeration: string;
        link_new_page: boolean;
    };
    type: BLOCK.EditorImage;
};
export declare type EditorGallery = any;
export declare type RawType = {
    data: {
        html: string;
    };
    type: BLOCK.Raw;
};
export declare type QuoteType = {
    data: {
        text: string;
        caption: string;
        alignment: string;
    };
    type: BLOCK.Quote;
};
export declare type CollectionItemType = {
    data: {
        id: string;
    }[];
    type: BLOCK.CollectionItem;
};
export declare type RelatedArticlesType = {
    data: {
        id: string;
    }[];
    type: BLOCK.RelatedArticles;
};
declare type EditorGalleryType = any;
export declare type BlockType = ParagraphType | HeadingType | TableType | ListType | EmbedType | CollectionItemType | QuoteType | RelatedArticlesType | EditorLiveBlogType | EditorImageType | EditorGalleryType | RawType | PollType;
export interface IMenu {
    id: number;
    name: string;
    resource_type: RESOURCE;
    resource_id: number;
    order: number;
    destination: 'same' | 'new';
    url: string;
    children: IMenu[];
}
export interface IAds {
    id: number;
    name: string;
    slug: string;
    content: string;
    position: string;
}
export interface ISettings {
    language: string;
    smartbar: ISmartbar;
    popup: IPopup;
    'name_website.value': string;
    'sidebar_dynamic_news_list.title': string;
    'article_next-prev.value': boolean;
    'article_show_settings.show_author': boolean;
    'article_show_settings.show_updated_at': boolean;
    'article_show_settings.show_comment_option': boolean;
    'article_show_settings.allow_comments_on_tag': boolean;
    'article_show_settings.sidebar_total_articles': number;
    'article_show_settings.hide_headline_articles_from_lists': true;
    'article_create_settings.show_source_field': boolean;
    'external_rss.url': string;
    'external_rss.title': string;
    'external_rss.enable': boolean;
    'external_rss.number_of_articles': number;
    'external_rss.url_read_more': string;
    'second_external_rss.url': string;
    'second_external_rss.title': string;
    'second_external_rss.enable': boolean;
    'second_external_rss.number_of_articles': number;
    'second_external_rss.url_read_more': string;
    'recaptcha.token': string;
    'google.analytic_id': null;
    'meta.title': string;
    'meta.description': string;
    'facebook.page_url': string;
    'twitter.page_url': string;
    'instagram.page_url': string;
    is_facebook_login_available: true;
    is_google_login_available: true;
    'website_images.default_image': string;
    'website_images.origin_default_image': string;
    'website_images.logo': string;
    'website_images.origin_logo': string;
    'website_images.fav_icons': string;
    'website_images.origin_fav_icon': string;
    'website_images.dark_logo': string;
    'website_images.origin_dark_logo': string;
    'pwa.icon': string;
    'pwa.origin_icon': string;
    'pwa.splash': string;
    'pwa.origin_splash': string;
    domain: string;
    footer_text?: string;
}
export interface IThumbnails {
    origin: string | null;
    xsmall_300?: string | null;
    xsmall_400?: string | null;
    medium?: string | null;
    fullurl?: string | null;
    watermark?: string | null;
}
export interface IPopup {
    title: string;
    content: {
        blocks: BlockType[];
    };
    formattedContent: string;
    htmlContent: string;
    jsonContent: {
        images?: IContentImage[];
        articles?: IRelatedArticle[];
        polls?: IArticlePoll[];
    };
    buttonText: string;
    link: string;
    visibility: VISIBILITY;
    links: string[];
    logoId: number;
    logoPath: string;
    reducedLogoPath: string;
    lastUpdateAt: string;
}
export interface ILatestComments {
    url: string;
    user_url: string;
    claps_count: number;
    content: string;
    date: string;
    resource: string;
    user: string;
    user_avatar: string;
}
export interface IArticleComment {
    id: number;
    content: string;
    replies_count: number;
    likes_count: number;
    username: string;
    user_id: number;
    user_likes: number;
    user_avatar: string;
    user_avatar_origin: string;
    user_url: string;
    level: number;
    created_at: string;
    updated_at: string;
    can_like_it: boolean;
    can_report_it: boolean;
    can_edit: boolean;
    can_delete: boolean;
    show_as_dark: boolean;
    author_role: string;
    show_author_role: boolean;
    show_the_badge: boolean;
    replies: IArticleComment[];
}
export interface IUser {
    id: number;
    name: string;
    username: string;
    email: string;
    provider: string | null;
    provider_id: string | null;
    fb_user_access_token?: null;
    image: string;
    status: string;
    custom_data: {
        test: string;
        android_telefoon: string;
    };
    date_of_birth: string;
    settings: {
        night_mode: boolean;
        notifications?: boolean;
        notify_by_likes: boolean;
        notify_by_replies: boolean;
        notify_by_likes_on_email?: boolean;
        notify_by_replies_on_email?: boolean;
    };
    thumbnails: {
        xsmall_300: string;
        xsmall_400: string;
        medium: string;
        origin: string;
        fullurl: string;
    };
    last_login: string;
    created_at?: string;
    updated_at?: string;
    is_public: boolean;
    enable_notifications_popup: boolean;
    claps_count: number;
    profile_image: string;
    origin_profile_image: string;
}
export interface IAuthor {
    id: number;
    is_public: boolean;
    name: string;
    username: string;
    author_url: string;
    avatar: string | null;
    articles?: IArticle[];
    avatar_origin_url: string | null;
    links?: {
        twitter: string;
    };
    description?: string;
}
export interface ITag {
    id: number;
    title: string;
    meta_title: string;
    url: string;
    slug: string;
    claps_users_count: number;
    claps_count: number;
}
export interface IArticle {
    id: number;
    slug: string;
    title: string;
    a_title: string | null;
    b_title: string | null;
    abtesting: boolean | null | undefined;
    excerpt: string;
    bold_title?: number;
    author: IAuthor;
    published_at: string;
    updated_at: string;
    disable_ads: boolean;
    image: string;
    primary_tag: ITag;
    tags: ITag[];
    comments_count: number;
    claps_count: number;
    claps_users_count: number;
    views: number;
    content?: {
        time: number;
        blocks: BlockType[];
        version: string;
    };
    related_articles?: IRelatedArticle[];
    related_polls?: IArticlePoll[];
    related_items?: number[];
    content_images?: IContentImage[];
    url: string;
    meta_title: string;
    meta_description: string | null;
    thumbnails: IThumbnails;
    thumbnails_without_watermark: IThumbnails;
    rrsLink?: string;
    type: ARTICLE_TYPE;
    in_headline?: ARTICLE_HEADLINE;
    enable_comments: boolean;
    is_sticky?: boolean;
    is_bold: boolean;
    watermark?: string;
    source: string | null;
    source_url: string | null;
}
export declare type RouteItem = {
    label: string;
    path?: string;
    isActive: boolean;
    children?: RouteItem[];
};
export declare type NotificationsHookData = {
    notifications: INotification[];
    settingsRoute: string;
    newNotificationsCount: number;
    clearNewNotifications: () => void;
    handleReadNotificationById?: (id: any) => void;
    handleReadAllNotifications: () => void;
    paginate: () => void;
    reloadNotifications: () => void;
    labels: {
        title: string;
        readAll: string;
        readMore: string;
        settings: string;
    };
};
export declare type Article = {
    id: number;
    slug: string;
    title: string;
    a_title: string;
    b_title: string;
    abtesting: boolean;
    excerpt: string;
    author: IAuthor;
    published_at: string;
    updated_at: string;
    disable_ads: boolean;
    image: string;
    primary_tag: ITag;
    tags: ITag[];
    comments_count: number;
    claps_count: number;
    claps_users_count: number;
    views: number;
    content: {
        time: number;
        blocks: BlockType[];
        version: string;
    };
    related_articles: IRelatedArticle[];
    related_polls: IArticlePoll[];
    related_items: number[];
    content_images: IContentImage[];
    url: string;
    meta_title: string;
    meta_description: string;
    thumbnails: IThumbnails;
    thumbnails_without_watermark: IThumbnails;
    rrsLink?: string;
    type: ARTICLE_TYPE;
    in_headline: ARTICLE_HEADLINE;
    enable_comments: boolean;
    is_bold: boolean;
    source: string;
    source_url: string;
};
export declare type Comment = {
    id: number;
    content: string;
    replies_count: number;
    likes_count: number;
    username: string;
    user_id: number;
    user_likes: number;
    user_avatar: string;
    replay_to: number;
    user_avatar_origin: string;
    user_url: string;
    level: number;
    created_at: string;
    updated_at: string;
    can_like_it: boolean;
    can_report_it: boolean;
    can_edit: boolean;
    can_delete: boolean;
    show_as_dark: boolean;
    author_role: string;
    show_author_role: boolean;
    show_the_badge: boolean;
    replies: Array<Comment>;
};
export declare type CommentSummary = {
    url: string;
    user_url: string;
    claps_count: number;
    replies_count: number;
    content: string;
    date: string;
    resource: string;
    user: string;
    user_avatar: string;
};
export declare type PublicUserComment = {
    id: number;
    content: string;
    date: string;
    date_and_time: string;
    replies_count: number;
    likes_count: number;
    username: 'string';
    user_id: number;
    user_likes: number;
    user_avatar: null;
    user_avatar_origin: null;
    user_url: 'string';
    level: number;
    replies: [];
    can_like_it: boolean;
    status: string;
    created_at: string;
    updated_at: string;
    flagged: number;
    show_as_dark: boolean;
    author_role: string;
    show_author_role: boolean;
    show_the_badge: boolean;
    can_edit: boolean;
    can_delete: boolean;
    url: string;
};
export declare type PublicUser = {
    id: number;
    name: string;
    username: string;
    avatar: string;
    avatar_origin_url: string;
    public_url: string;
    author_url: string;
    status: 'active' | 'new';
    custom_data: any;
    links: {
        twitter: string;
    };
    created_at: string;
    comments_count: number;
    claps_count: number;
};
export declare type LatestComment = {
    url: string;
    user_url: string;
    claps_count: number;
    content: string;
    date: string;
    resource: string;
    user: string;
    user_avatar: string;
};
export interface ILoginProps extends IFormControllerProps<TLoginFormData> {
    showForgotPassword?: () => void;
    showRegister?: () => void;
    socialLogin?: ISocialLoginProps;
    labels?: {
        title?: string;
        hint?: string;
        username?: string;
        usernamePlaceholder?: string;
        password?: string;
        passwordPlaceholder?: string;
        registerBtn?: string;
        login?: string;
    };
}
export interface ISocialLoginProps {
    hasFacebookLogin?: boolean;
    loginWithFacebook: () => void;
    hasGoogleLogin?: boolean;
    loginWithGoogle: () => void;
}
export declare type TLoginFormData = {
    login: string;
    password: string;
};
export interface IModalProps {
    show: boolean;
    size: SIZE;
    onClose: (e?: any) => void;
    onOpen?: (e?: any) => void;
    backgroundColor?: string;
    children?: React.ReactNode;
}
export interface IUserChangePasswordFormData {
    current_password: string;
    password: string;
    password_confirmation: string;
}
export interface INotification {
    id: string;
    read_at: string;
    open_at: string;
    created_at: string;
    url: string;
    type: string;
    resource_title: string;
    resource_type: string;
    user_name: string;
    text: string;
    comment: string;
    user_url: string;
    resource_id: number;
    comment_id: number;
    user_avatar: string;
}
export interface ICollectionItem {
    id: number;
    title: string;
    claps_count: number;
    enable_comments: boolean;
    claps_users_count: number;
    meta_title: string;
    meta_description: string;
    comments_count: number;
    slug: string;
    content: {
        time: number;
        blocks: BlockType[];
        version: string;
    };
    fields: IFieldBlock[] | ISimpleFieldBlock[];
    collection_id: number;
    collection: ICollection;
    views: number;
    is_category: boolean;
    is_visible: boolean;
}
export interface ICollection {
    id: number;
    name: string;
    slug: string;
    meta_title: string;
    meta_description: string;
    views: number;
    content: {
        time: number;
        blocks: BlockType[];
        version: string;
    };
    created_at: string;
    comments_count: number;
    updated_at: string;
    is_filterable: boolean;
}
export interface IFieldBlock {
    field: {
        id: number;
        type: string;
        label: string;
    };
    value: {
        id: number;
        tag_id: number;
        value: any;
    };
}
export interface ISimpleFieldBlock {
    id: number;
    label: string;
    type: string;
    value: any;
}
export declare type DefaultArticlesListProps<T> = T & {
    data: {
        title: string;
        articles: IArticle[];
        hasPagination?: boolean;
        loading?: boolean;
        paginate?: () => void;
        group?: string;
        paginationLabel?: string;
        handleEmitAbTestResult?: (e?: unknown) => void;
    };
};
export declare type IArticleCardProps<T> = T & {
    data: IArticle;
    handleEmitAbTestResult?: (e?: any) => void;
    loader: any;
    group?: string;
};
export declare type TVerticleListOptionsProps = {
    showBorder?: boolean;
    showCounts?: boolean;
    showDateOf?: boolean;
    padding?: SIZES_OPTIONS;
    readMoreLink?: string;
    gap?: SIZES_OPTIONS;
    imageRounded?: SIZES_OPTIONS;
    rounded?: SIZES_OPTIONS;
    titleSize?: SIZES_OPTIONS;
    showDateGroup?: boolean;
    showImage?: boolean;
    hideOnMobile?: boolean;
    showArrow?: boolean;
    hasPagination: true;
};
export declare type THorizontalListOptionsProps = {
    showCounts?: boolean;
    showDateOf?: boolean;
    showDescription?: boolean;
    rounded?: SIZES_OPTIONS;
    title?: string;
    countsOutside?: boolean;
    group?: string;
    showTag?: boolean;
    sliderOnMobile?: boolean;
    showDateGroup?: boolean;
    showAuthor?: boolean;
    tagOutside?: boolean;
};
export declare type TSummaryListOptionsProps = {
    showCounts?: boolean;
    title?: string;
};
export declare type TDetailedListOptions = {
    showCounts?: boolean;
    showDateOf?: boolean;
    padding?: SIZES_OPTIONS;
    readMoreLink?: string;
    rounded?: SIZES_OPTIONS;
    showDescription?: boolean;
    showAuthor?: boolean;
    showTag?: boolean;
    imageRounded?: SIZES_OPTIONS;
    showDateGroup?: boolean;
};
export declare type TArticleListOptions = {
    seeAllRoute?: Route | any;
    showBorder?: boolean;
    likeIcon?: 'thumbsup' | 'heart' | 'claps';
    showCounts?: boolean;
    showDateOf?: boolean;
    padding?: SIZES_OPTIONS;
    title?: string;
    authorBy?: boolean;
    sliderOnMobile?: boolean;
    authorIsPremium?: boolean;
    showArticleTitle?: boolean;
    smallImage?: boolean;
    showAuthorIcon?: boolean;
    gap?: SIZES_OPTIONS;
    showBackgroundTitle?: boolean;
    readMoreLink?: string;
    showColoredLine?: boolean;
    showAuthor?: boolean;
    tagOutside?: boolean;
    hasPagination?: boolean;
    rounded?: SIZES_OPTIONS;
    tagOutline?: boolean;
    showImage?: boolean;
    showDate?: boolean;
    showDiscription?: boolean;
    showTopLeftIcon?: boolean;
    countsOutside?: boolean;
    showDateGroup?: boolean;
    showDateWithCounts?: boolean;
    hideOnMobile?: boolean;
    buttonRounded?: SIZES_OPTIONS;
    cardRounded?: SIZES_OPTIONS;
    imageRounded?: SIZES_OPTIONS;
    tagRounded?: SIZES_OPTIONS;
    showArrow?: boolean;
    showTag?: boolean;
    titleSize?: SIZES_OPTIONS;
    articleView?: ARTICLE_VIEW_TYPES;
    layout?: ARTICLESLIST_LAYOUT_TYPE;
    smallerCard?: boolean;
    group?: string;
};
export declare type TFeaturedArticlesOptions = {
    showCounts?: boolean;
    showDateOf?: boolean;
    mobileLayoutStyle?: FEATURED_MOBILE;
    showTag?: boolean;
    numberOfSmallArticles?: SMALL_FEATURED_NUM;
    showAuthor?: boolean;
    showInfoOutside?: boolean;
    gap?: SIZES_OPTIONS;
    rounded?: SIZES_OPTIONS;
    showColoredLine?: boolean;
};
export interface IFeaturedArticlesListData {
    data: {
        bigArticles?: IArticle[];
        smallArticles?: IArticle[];
    };
}
export declare type TTabComponentOptions = {
    tabsTitle: {
        title?: string;
        icon?: string;
    }[];
    activeTabIndex?: number;
    styles?: TAB_STYLES;
};
export declare type TFooterOptions = {
    showSocialLinks?: boolean;
    showMenu?: boolean;
    showSiteMap?: boolean;
    backgroundColorOnLightMode?: string;
    backgroundColorOnDarkMode?: string;
};
export declare type TCommentsComponentOptions = {
    resourceType: RESOURCE.Tag;
};
export declare type TInteractiveCommentsOptions = {
    moderatorIcon?: boolean;
    premiumIcon?: boolean;
    showAvatar?: boolean;
    avatarRounded?: SIZES_OPTIONS;
    inputRounded?: SIZES_OPTIONS;
    showActions?: boolean;
};
export interface ISummeryArticlesProps {
    data: {
        title: string;
        articles: IArticle[];
        groupedArticles: {
            [key: string]: IArticle[];
        };
        group: string;
        loading: boolean;
        hasPagination?: boolean;
        paginationLabel?: string;
        paginate?: (e?: any) => void;
        handleEmitAbTestResult?: (e?: any) => void;
        seeAllRoute?: Route;
    };
    options?: {
        showCounts: boolean;
        showDate: boolean;
        articleView: ARTICLE_VIEW_TYPES;
        allowHorivontalScroll: boolean;
        showArrow?: boolean;
        title?: string | undefined;
    };
}
export declare type TFlexComponentOptions = {
    childrensDimension: GRID_DIMENSIONS;
    gap?: SIZES_OPTIONS;
};
export declare type BreadCrumbProps = {
    basePath: string;
    pathes: Array<Route>;
};
export declare type TBreadCrumbOptions = {
    deviderIcon?: DEVIDER_BREADCRUMB;
    homeIcon?: HOMEICON_BREADCRUMB;
    homeType?: HOMETYPE_BREADCRUMB;
    homeText?: string;
    logo?: string;
};
export interface IComponentRegistry {
    uuid: string;
    id: string;
    options?: THeaderOptions | TSocialShare | TVerticleListOptionsProps | THorizontalListOptionsProps | TDetailedListOptions | TFeaturedArticlesOptions | TTabComponentOptions | TArticleHeaderOptions | TCommentsComponentOptions | TFlexComponentOptions | TBreadCrumbOptions | TInteractiveCommentsOptions | TAdvertisComponentOptions | TFooterOptions;
    hookConfig?: any;
    page?: string[];
    variation?: string;
    children?: IComponentRegistry[];
}
export interface IBuildifireRegistryNew {
    version: string;
    components: IComponentRegistry[];
}
export declare type TSocialShare = {
    justifyEnd?: boolean;
};
export declare type TArticleHeaderOptions = {
    showCategory?: boolean;
    showDate?: boolean;
    showComments?: boolean;
    showLikes?: boolean;
    showAuthor?: boolean;
    showAuthorPhoto?: boolean;
    titleLocation?: ARTICLE_HEADER_TITLE_LOCATION;
    titleAlignment?: ARTICLE_HEADER_TITLE_ALIGNMENT;
};
export declare type TArticleHeaderData = {
    title: string;
    image: string;
    tagRedirectUrl?: string;
    tagTitle?: string;
    watermark?: string;
    date?: string;
    commentsCount?: number;
    likesCount?: number;
};
export declare type TAdvertisComponentOptions = {
    adContent?: string;
    minHeight?: string;
};
export declare type THeaderOptions = {
    showSocialLinksTop?: boolean;
    showSocialLinksBottom?: boolean;
    showLinksTop?: boolean;
    showLinksBottom?: boolean;
    showDrawer?: boolean;
    showDarkMode?: boolean;
    showSearch?: boolean;
    showSearchBoxInline?: boolean;
    backgroundColorOnLightMode?: string;
    backgroundColorOnDarkMode?: string;
};
export interface ILayoutRegistry {
    layout: LAYOUT_TYPE;
}
export interface IBuildifireRegistry {
    version: string;
    layout: LAYOUT_TYPE;
    components: {
        [key: string]: IComponentRegistry[];
    };
}
export interface IParametersCheck {
    checked: boolean;
}
export interface IParametersCounter {
    max: number;
    min: number;
    step: number;
}
export interface IObject<T extends ObjectType> {
    type: T;
    parameters: ParameterMap[T];
}
declare type ParameterMap = {
    checked: IParametersCheck;
    counter: IParametersCounter;
};
export declare type ObjectType = keyof ParameterMap;
export interface IMetadataControllerProps {
    title?: string;
    description?: string;
    image?: string;
    url?: string;
    canonicalUrl?: string;
    ampUrl?: string;
    type?: string;
    author?: string;
    date?: string;
}
export interface IResourceActionProps {
    resource: IArticle | ITag | ICollectionItem;
    resourceType: RESOURCE;
}
export interface IUseShareResourceHookData {
    shareResourceUrl: string;
    shareResourceTitle: string;
    shareOnFacebook: () => void;
    shareOnLinkedIn: () => void;
    shareOnTwitter: () => void;
    shareOnWhatsapp: () => void;
    isCopied: boolean;
    copyLink: () => void;
}
export interface ILiveBlog {
    title: string;
    updated_at: string;
    id: number;
    is_pinned: number;
    content: BlockType[];
    content_images: IContentImage[];
}
export interface ILiveBlogData {
    liveblogs: ILiveBlog[];
    ads: IAds;
    blocks_count_to_place_ad: number;
}
export interface IPoll {
    poll_id: number;
    is_closed: boolean;
    my_answer: number;
    question: string;
    total_voting: number;
    answers: {
        id: number;
        answer: string;
        answer_voting: number;
    }[];
}
export declare type UseArticlesListProps = {
    scope?: ARTICLES_SCOPE;
    title?: string;
    paginationLabel?: string;
    tagId: number;
    size?: number;
    defaultOffset?: number;
    scopeValue?: string;
    limit?: number;
    hasPagination?: boolean;
    options: any;
    isSticky: boolean;
    openedArticleId?: string | null;
    initialPageSize: number;
    initialOffset: number;
    paginationPageSize: number;
    excludeVisibleHeadlines: boolean;
};
export interface IUseClapResourceHookProps {
    usersCount: number;
    clapsCount: number;
    clapResource: () => void;
}
export declare type UseRelatedArticlesData = {
    nextArticle: IArticle | null;
    prevArticle: IArticle | null;
};
export interface IUseCommentHookProps {
    level?: number;
    parentId?: number;
    comment: Comment;
    comments: Comment[];
    setCommentsCount: React.Dispatch<React.SetStateAction<number>>;
    setComments: React.Dispatch<React.SetStateAction<Comment[]>>;
    resourceType: RESOURCE;
    resourceId: number;
}
export interface IUseCommentHookData {
    level: number;
    comment: IComment;
    userLikes: number;
    hasUserLikedComment: boolean;
    commentLikes: number;
    hasUserReportedComment: boolean;
    showReplyModal: boolean;
    handleOpenReplyModal: (onOpen: boolean) => void;
    isUserComment: () => boolean;
    handleReplyComment: (comment: string) => void;
    handleLikeComment: () => void;
    handleUpdateComment: (comment: string) => void;
    handleDeleteComment: () => void;
    handleReportComment: () => void;
    labels: {
        reportCommentError: string;
        reportCommentSuccess: string;
        like: string;
    };
}
export interface IComment {
    id: number;
    content: string;
    replies_count: number;
    likes_count: number;
    username: string;
    user_id: number;
    user_likes: number;
    replay_to: number;
    user_avatar: string;
    user_avatar_origin: string;
    user_url: string;
    level: number;
    created_at: string;
    updated_at: string;
    can_like_it: boolean;
    can_report_it: boolean;
    can_edit: boolean;
    can_delete: boolean;
    show_as_dark: boolean;
    author_role: string;
    show_author_role: boolean;
    show_the_badge: boolean;
    replies: IComment[];
}
export interface IUseCommentFormHookProps {
    isReply?: boolean;
    isUpdate?: boolean;
    defaultComment?: string;
    hideCommentBox?: (e?: any) => void;
    handleCommentAction: (comment: string) => void;
}
export interface ICommentFormData {
    content: string;
}
export interface IUseCommentFormHookData extends IFormControllerProps<ICommentFormData> {
    isReply?: boolean;
    isUpdate?: boolean;
    labels: {
        label: string;
        placeholder: string;
        cancle: string;
        submit: {
            update: string;
            reply: string;
            comment: string;
        };
    };
}
export interface IUseCommentsHookData {
    enableComments: boolean;
    comments: Comment[];
    commentsCount: number;
    setCommentsCount: React.Dispatch<React.SetStateAction<number>>;
    resourceType: RESOURCE;
    resourceId: number;
    setComments: React.Dispatch<React.SetStateAction<Comment[]>> | ((e?: any) => void);
    commentsLoading: boolean;
    hasMoreComments: boolean;
    isSingleComment: boolean;
    handleLoadComments: (offest?: number) => void;
    handlePostComment: (comment: string) => void;
    useCommentForm: (props: IUseCommentFormHookProps | any) => IUseCommentFormHookData | any;
    useCommentListener: (props: IUseCommentListenerHookProps | any) => IUseCommentListenerHookData | any;
    useComment: (props: IUseCommentHookProps | any) => IUseCommentHookData | any;
    labels?: {
        comment?: string;
        comments?: string;
        showAllComments?: string;
        readMoreComments?: string;
    };
}
export interface IPublicUser {
    id: number;
    name: string;
    username: string;
    avatar: string;
    avatar_origin_url: string;
    public_url: string;
    author_url: string;
    status: 'active' | 'new';
    custom_data: any;
    links: {
        twitter: string;
    };
    created_at: string;
    comments_count: number;
    claps_count: number;
}
export interface IUsePublicUserCommentsHookProps {
    user: IPublicUser;
}
export interface IUsePublicUserCommentsHooksData {
    comments: PublicUserComment[];
    loading: boolean;
    paginate: (e?: any) => void;
}
export interface IFilterOption {
    id: number;
    value: string;
    count: number;
    checked?: boolean;
}
export interface ICollectionAction {
    id: number;
    label: string;
    render_as: string;
    meta_type: string | null;
    type: string;
    has_more_options: boolean;
    order: number;
    action_meta: any;
    options: IFilterOption[];
    direction?: 'asc' | 'desc';
    selected?: boolean;
    value?: string | number[] | string[];
}
export interface IResource {
    resource: any;
    key: RESOURCE;
    other: any;
}
export interface IFile {
    id: number;
    route: string;
    content: string;
    redirect_url: string;
}
export interface IPublicUserComment {
    id: number;
    content: string;
    date: string;
    date_and_time: string;
    replies_count: number;
    likes_count: number;
    username: 'string';
    user_id: number;
    user_likes: number;
    user_avatar: null;
    user_avatar_origin: null;
    user_url: 'string';
    level: number;
    replies: [];
    can_like_it: boolean;
    status: string;
    created_at: string;
    updated_at: string;
    flagged: number;
    show_as_dark: boolean;
    author_role: string;
    show_author_role: boolean;
    show_the_badge: boolean;
    can_edit: boolean;
    can_delete: boolean;
    url: string;
}
export interface IForum {
    id: number;
    title: string;
    last_comment_date: string;
    created_at: string;
    meta_title: string;
    meta_description: string;
    published_at: string;
    comments_count: number;
    claps_count: number;
    claps_users_count: number;
    url: string;
    author: IAuthor;
    content: {
        blocks: BlockType[];
    };
    slug: string;
    image_id: number;
    image: string;
    thumbnails: IThumbnails;
    thumbnails_with_watermark: IThumbnails;
    related_polls: IArticlePoll[];
    related_articles: IRelatedArticle[];
    related_images: IContentImage[];
    content_images: IContentImage[];
    related_items: number[];
    enable_comments?: boolean;
}
export interface IFormControllerProps<T extends FieldValues> {
    register: UseFormRegister<T>;
    submit: () => Promise<void>;
    errors?: FieldErrors<T>;
    setError?: UseFormSetError<T>;
    reset?: UseFormReset<T>;
    watch?: UseFormWatch<T>;
    getValues?: UseFormGetValues<T>;
    setValue?: UseFormSetError<T>;
}
export interface IPublicUserDataProps {
    settings: ISettings;
    mainMenu?: IMenu;
    user: IPublicUser;
}
export interface ICommonPageData {
    settings: ISettings;
    mainMenu?: IMenu;
    bigArticles?: IArticle[];
    smallArticles?: IArticle[];
    registry: IBuildifireRegistry;
}
export interface IAuthorDataProps {
    settings: ISettings;
    mainMenu?: IMenu;
    author: IAuthor;
}
export declare type ArticleAsListElement = Omit<IArticle, 'content_images' | 'claps_users_count' | 'claps_count' | 'tags' | 'content' | 'related_articles' | 'views' | 'related_polls' | 'related_items' | 'source_url' | 'source' | 'disable_ads' | 'claps_count' | 'enable_comments' | 'in_headline' | 'type' | 'thumbnails_without_watermark' | 'meta_description' | 'meta_title' | 'updated_at'>;
export {};
